@@ -1,4 +1,6 @@
+from .action_precision_recall_calculator import PrecisionRecallCalculator
+from .consistent_models_calculator import calculate_number_consistent_models, SafeConsistentModelsCalculator
 from .action_model_statistics_extractor import AMStatisticsExtractor
-from .learned_domain_validator import DomainValidator, ValidationResult
 from .domain_comparison import switch_comparisons_and_sort, validate_add_effects, validate_delete_effects, \
 	validate_preconditions, validate_action_model
+from .learned_domain_validator import DomainValidator, ValidationResult
